# acdc

## Wanna-be fast string searcher

**beta**

[![Two planes joined with electric arcs](https://images.unsplash.com/photo-1534224039826-c7a0eda0e6b3?ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&ixlib=rb-1.2.1&auto=format&fit=crop&w=1050&q=80)](https://unsplash.com/photos/ImcUkZ72oUs)